@@ -1708,3 +1708,125 @@ def test_dataclass_args_init_with_default(input_value, extra_behavior, expected)
             assert exc_info.value.errors(include_url=False) == expected.errors
     else:
         assert dataclasses.asdict(v.validate_python(input_value)) == expected
+
+
+@dataclasses.dataclass
+class BasicDataclass:
+    a: str
+
+
+def test_alias_allow_pop(py_and_json: PyAndJson):
+    schema = core_schema.dataclass_schema(
+        BasicDataclass,
+        core_schema.dataclass_args_schema(
+            'BasicDataclass',
+            [
+                core_schema.dataclass_field(name='a', schema=core_schema.str_schema(), validation_alias='FieldA'),
+            ],
+        ),
+        ['a'],
+        config=core_schema.CoreConfig(validate_by_name=True, validate_by_alias=True),
+    )
+    v = py_and_json(schema)
+    assert v.validate_test({'FieldA': 'hello'}) == BasicDataclass(a='hello')
+    assert v.validate_test({'a': 'hello'}) == BasicDataclass(a='hello')
+    assert v.validate_test(
+        {
+            'FieldA': 'hello',
+            'a': 'world',
+        }
+    ) == BasicDataclass(a='hello')
+    with pytest.raises(ValidationError, match=r'FieldA\n +Field required \[type=missing,'):
+        assert v.validate_test({'foobar': 'hello'})
+
+
+def test_only_validate_by_name(py_and_json) -> None:
+    schema = core_schema.dataclass_schema(
+        BasicDataclass,
+        core_schema.dataclass_args_schema(
+            'BasicDataclass',
+            [
+                core_schema.dataclass_field(name='a', schema=core_schema.str_schema(), validation_alias='FieldA'),
+            ],
+        ),
+        ['a'],
+        config=core_schema.CoreConfig(validate_by_name=True, validate_by_alias=False),
+    )
+    v = py_and_json(schema)
+    assert v.validate_test({'a': 'hello'}) == BasicDataclass(a='hello')
+    with pytest.raises(ValidationError, match=r'a\n +Field required \[type=missing,'):
+        assert v.validate_test({'FieldA': 'hello'})
+
+
+def test_only_allow_alias(py_and_json) -> None:
+    schema = core_schema.dataclass_schema(
+        BasicDataclass,
+        core_schema.dataclass_args_schema(
+            'BasicDataclass',
+            [
+                core_schema.dataclass_field(name='a', schema=core_schema.str_schema(), validation_alias='FieldA'),
+            ],
+        ),
+        ['a'],
+        config=core_schema.CoreConfig(validate_by_name=False, validate_by_alias=True),
+    )
+    v = py_and_json(schema)
+    assert v.validate_test({'FieldA': 'hello'}) == BasicDataclass(a='hello')
+    with pytest.raises(ValidationError, match=r'FieldA\n +Field required \[type=missing,'):
+        assert v.validate_test({'a': 'hello'})
+
+
+@pytest.mark.parametrize('config_by_alias', [None, True, False])
+@pytest.mark.parametrize('config_by_name', [None, True, False])
+@pytest.mark.parametrize('runtime_by_alias', [None, True, False])
+@pytest.mark.parametrize('runtime_by_name', [None, True, False])
+def test_by_alias_and_name_config_interaction(
+    config_by_alias: Union[bool, None],
+    config_by_name: Union[bool, None],
+    runtime_by_alias: Union[bool, None],
+    runtime_by_name: Union[bool, None],
+) -> None:
+    """This test reflects the priority that applies for config vs runtime validation alias configuration.
+
+    Runtime values take precedence over config values, when set.
+    By default, by_alias is True and by_name is False.
+    """
+
+    if config_by_alias is False and config_by_name is False and runtime_by_alias is False and runtime_by_name is False:
+        pytest.skip("Can't have both by_alias and by_name as effectively False")
+
+    core_config = {
+        **({'validate_by_alias': config_by_alias} if config_by_alias is not None else {}),
+        **({'validate_by_name': config_by_name} if config_by_name is not None else {}),
+    }
+
+    @dataclasses.dataclass
+    class MyDataclass:
+        my_field: int
+
+    schema = core_schema.dataclass_schema(
+        MyDataclass,
+        core_schema.dataclass_args_schema(
+            'MyDataclass',
+            [
+                core_schema.dataclass_field(
+                    name='my_field', schema=core_schema.int_schema(), validation_alias='my_alias'
+                ),
+            ],
+        ),
+        ['my_field'],
+        config=core_schema.CoreConfig(**core_config),
+    )
+    s = SchemaValidator(schema)
+
+    alias_allowed = next(x for x in (runtime_by_alias, config_by_alias, True) if x is not None)
+    name_allowed = next(x for x in (runtime_by_name, config_by_name, False) if x is not None)
+
+    if alias_allowed:
+        assert dataclasses.asdict(
+            s.validate_python({'my_alias': 1}, by_alias=runtime_by_alias, by_name=runtime_by_name)
+        ) == {'my_field': 1}
+    if name_allowed:
+        assert dataclasses.asdict(
+            s.validate_python({'my_field': 1}, by_alias=runtime_by_alias, by_name=runtime_by_name)
+        ) == {'my_field': 1}
